@@ -1,6 +1,6 @@
-use super::*;
+use {super::*, CompileErrorKind::*};
 
-use CompileErrorKind::*;
+const VALID_ALIAS_ATTRIBUTES: [Attribute; 1] = [Attribute::Private];
 
 #[derive(Default)]
 pub(crate) struct Analyzer<'src> {
@@ -195,6 +195,15 @@ impl<'src> Analyzer<'src> {
       }));
     }
 
+    for attr in &alias.attributes {
+      if !VALID_ALIAS_ATTRIBUTES.contains(attr) {
+        return Err(alias.name.token().error(AliasInvalidAttribute {
+          alias: name,
+          attr: *attr,
+        }));
+      }
+    }
+
     Ok(())
   }
 
