@@ -1,6 +1,7 @@
-use super::*;
-
-use std::{borrow::Cow, mem};
+use {
+  super::*,
+  std::{borrow::Cow, mem},
+};
 
 /// Construct a `Tree` from a symbolic expression literal. This macro, and the
 /// Tree type, are only used in the Parser unit tests, providing a concise
@@ -133,12 +134,12 @@ impl Display for Tree<'_> {
           if i > 0 {
             write!(f, " ")?;
           }
-          write!(f, "{}", child)?;
+          write!(f, "{child}")?;
         }
 
         write!(f, ")")
       }
-      Tree::Atom(text) => write!(f, "{}", text),
+      Tree::Atom(text) => write!(f, "{text}"),
     }
   }
 }
