@@ -53,6 +53,14 @@ test! {
   status: EXIT_FAILURE,
 }
 
+test! {
+  name: check_found_diff_quiet,
+  justfile: "x:=``\n",
+  args: ("--unstable", "--fmt", "--check", "--quiet"),
+  stderr: "",
+  status: EXIT_FAILURE,
+}
+
 test! {
   name: check_diff_color,
   justfile: "x:=``\n",
@@ -243,7 +251,7 @@ test! {
 }
 
 test! {
-  name: assignment_parenthized_expression,
+  name: assignment_parenthesized_expression,
   justfile: "
     foo := ('foo')
   ",
@@ -1042,3 +1050,12 @@ test! {
         echo foo
   ",
 }
+
+#[test]
+fn exported_parameter() {
+  Test::new()
+    .justfile("foo +$f:")
+    .args(&["--dump"])
+    .stdout("foo +$f:\n")
+    .run();
+}
