@@ -22,6 +22,7 @@ fn alias() {
         "f": {
           "name": "f",
           "target": "foo",
+          "attributes": [],
         }
       },
       "assignments": {},
@@ -230,7 +231,7 @@ fn dependency_argument() {
             "arguments": [
               "baz",
               "baz",
-              ["concatinate", "a", "b"],
+              ["concatenate", "a", "b"],
               ["evaluate", "echo"],
               ["variable", "x"],
               ["if", "==", "a", "b", "c", "d"],
@@ -299,6 +300,7 @@ fn duplicate_recipes() {
       "first": "foo",
       "aliases": {
         "f": {
+          "attributes": [],
           "name": "f",
           "target": "foo",
         }
